<?xml version='1.0' ?>
<!-- CAM kit utility program -->
<!-- Provided "as is" License: Creative Commons - http://creativecommons.org/licenses/by-sa/3.0/
	Authors: David RR Webber, May, 2008 -->
<!--
	Purpose  : Parse UBL genericode codelist XML instance.
	Output to CAM lookup table format.
	Original : 06/15/2008
	Initials : drrw
	CAM ver    : 1.1 
	Description : Simple format converter.

	Updated  - Inits - Change
	06/15/08   drrw   Initial release 
	09/02/09   ksall  Set 'alt' values to data from last column and include more GC metadata.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:gc="http://genericode.org/2006/ns/CodeList/0.4/"
	xmlns:look="http://jcam.org.uk/LookupLists">
	<xsl:output method="xml" indent="yes" omit-xml-declaration="no"/>
	<xsl:variable name="version">1.0</xsl:variable>
	
	<xsl:template match="/">		
		<look:LookupList xmlns:look="http://jcam.org.uk/LookupLists">
			<xsl:attribute name="name">
				<xsl:value-of select="gc:CodeList/Identification/ShortName"/>
			</xsl:attribute>
			
			<!-- Add useful genericode metadata as comments. -->
<xsl:comment xml:space="preserve">
	<xsl:text>List Identifier = </xsl:text><xsl:value-of select="gc:CodeList/Identification/LongName[@Identifier='listID']"/>
	<xsl:text>Canonical URI = </xsl:text><xsl:value-of select="gc:CodeList/Identification/CanonicalUri"/>		
	<xsl:text>Location URI = </xsl:text><xsl:value-of select="gc:CodeList/Identification/LocationUri"/>		
	<xsl:text>Number of Rows = </xsl:text><xsl:value-of select="count(gc:CodeList/SimpleCodeList/Row)"/>		
	<xsl:text>Number of Columns = </xsl:text><xsl:value-of select="count(gc:CodeList/ColumnSet/Column)"/>		
	<xsl:text>Setting lookup list "alt" attributes to values from column ID =  </xsl:text><xsl:value-of select="/gc:CodeList/ColumnSet/Column[last()]/@Id"/>		
</xsl:comment>	
			
			<xsl:for-each select="gc:CodeList/SimpleCodeList/Row">
				<look:item>
					<xsl:attribute name="name">
						<xsl:value-of select="Value[@ColumnRef='name']/SimpleValue"/>
					</xsl:attribute>
					<xsl:if test="count(/gc:CodeList/ColumnSet/Column) > 2">
						<!-- Set alt values to last column's content regardless of numColumns or Id. -->
						<xsl:attribute name="alt">
							<xsl:value-of select="Value[@ColumnRef][last()]/SimpleValue"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:value-of select="Value[@ColumnRef='code']/SimpleValue"/>
				</look:item>
			</xsl:for-each>
		</look:LookupList>
	</xsl:template>
	<xsl:template match="text()"/>
</xsl:stylesheet>